@@ -33,7 +33,6 @@ use opendal::raw::normalize_path;
 use opendal::EntryMode;
 use opendal::ErrorKind;
 use opendal::Metadata;
-use opendal::Metakey;
 use opendal::Operator;
 use sharded_slab::Slab;
 use tokio::sync::Mutex;
@@ -376,6 +375,11 @@ impl PathFilesystem for Filesystem {
         Err(libc::EOPNOTSUPP.into())
     }
 
+    async fn opendir(&self, _req: Request, path: &OsStr, flags: u32) -> Result<ReplyOpen> {
+        log::debug!("opendir(path={:?}, flags=0x{:x})", path, flags);
+        Ok(ReplyOpen { fh: 0, flags })
+    }
+
     async fn open(&self, _req: Request, path: &OsStr, flags: u32) -> Result<ReplyOpen> {
         log::debug!("open(path={:?}, flags=0x{:x})", path, flags);
 
@@ -712,7 +716,6 @@ impl PathFilesystem for Filesystem {
         let children = self
             .op
             .lister_with(&path)
-            .metakey(Metakey::ContentLength | Metakey::LastModified | Metakey::Mode)
             .await
             .map_err(opendal_error2errno)?
             .filter_map(move |entry| {
@@ -821,6 +824,20 @@ impl PathFilesystem for Filesystem {
             copied: u64::from(written),
         })
     }
+
+    async fn statfs(&self, _req: Request, path: &OsStr) -> Result<ReplyStatFs> {
+        log::debug!("statfs(path={:?})", path);
+        Ok(ReplyStatFs {
+            blocks: 1,
+            bfree: 0,
+            bavail: 0,
+            files: 1,
+            ffree: 0,
+            bsize: 4096,
+            namelen: u32::MAX,
+            frsize: 0,
+        })
+    }
 }
 
 const fn entry_mode2file_type(mode: EntryMode) -> FileType {
@@ -855,6 +872,10 @@ const fn dummy_file_attr(kind: FileType, now: SystemTime, uid: u32, gid: u32) ->
         gid,
         rdev: 0,
         blksize: 4096,
+        #[cfg(target_os = "macos")]
+        crtime: now,
+        #[cfg(target_os = "macos")]
+        flags: 0,
     }
 }
 
